==> fivecentplots-0.3.1.tar.gz: fivecentplots-0.3.1/fivecentplots/themes/white.py <==
#########################################################
# Figure layout defaults
#########################################################
fcp_params = {'ax_edge_color': '#555555',
              'ax_fill_color': '#ffffff',
              'ax_size': [400,400],  # [width, height]
              'box_divider_color': '#bbbbbb',
              'box_fill_color': '#eeeeee',
              'box_group_title_edge_color': '#ffffff',
              'box_group_title_fill_color': '#ffffff',
              'box_group_title_font_size': 13,
              'box_group_title_font_color': '#666666',
              'box_group_title_font_style': 'normal',
              'box_group_title_font_weight': 'normal',
              'box_group_label_edge_color': '#555555',
              'box_group_label_font_size': 12,
              'box_group_label_font_color': '#666666',
              'box_group_label_font_style': 'normal',
              'box_group_label_font_weight': 'normal',
              'cbar_size': 30,
              'cmap': 'inferno',
              'dpi': 100,
              'fig_edge_color': '#ffffff',
              'fig_fill_color': '#ffffff',
              'grid_major_color': '#dddddd',
              'grid_major_style': '-',
              'grid_major_width': 1.3,
              'grid_minor_color': '#eeeeee',
              'grid_minor_style': '-',
              'grid_minor_width': 0.5,
              'label_color': 'k',
              'label_font_size': 14,
              'label_style': 'italic',
              'label_weight': 'bold',
              'label_rc_edge_color': '#ffffff',
              'label_rc_fill_color': '#888888',
              'label_rc_font_size': 16,
              'label_rc_text_color': '#ffffff',
              'label_rc_text_style': 'normal',
              'label_rc_text_weight': 'bold',
              'label_rc_size': 30,
              'legend_fill_color': '#ffffff',
              'legend_edge_color': '#ffffff',
              'legend_font_size': 12,
              'legend_points': 1,
              'legend_title': '',
              'lines_width': 1,
              'marker_size': 7,
              'marker_type': 'o',
              'tick_labels_font_size': 12,
              'tick_labels_color': '#000000',
              'ticks_major_color': '#555555',
              'ticks_minor_color': '#999999',
              'ticks_major_length': 6,
              'ticks_major_width': 1.7,
              'title_fill_color': '#ffffff',
              'title_edge_color': '#ffffff',
              'title_font_color': '#333333',
              'title_font_size': 18,
              'title_font_weight': 'bold',
              'title_wrap_edge_color': '#5f5f5f',
              'title_wrap_fill_color': '#5f5f5f',
              'title_wrap_font_size': 16,
              'title_wrap_font_color': '#ffffff',
              'title_wrap_font_style': 'normal',
              'title_wrap_font_weight': 'bold',
              'title_wrap_size': 30,
              }

#########################################################
# New color schemes
#########################################################

# colors = []

####################################################
# Default marker scheme
####################################################

# markers = []

####################################################
# Matplotlib default overrides
####################################################
import matplotlib as mpl
rcParams = {'font.cursive': ['Apple Chancery',
                             'Textile',
                             'Zapf Chancery',
                             'Sand',
                             'cursive'],
            'font.fantasy': ['Comic Sans MS',
                             'Chicago',
                             'Charcoal',
                             'ImpactWestern',
                             'fantasy'],
            'font.monospace': ['Bitstream Vera Sans Mono',
                               'DejaVu Sans Mono',
                               'Andale Mono',
                               'Nimbus Mono L',
                               'Courier New',
                               'Courier',
                               'Fixed',
                               'Terminal',
                               'monospace'],
            'font.sans-serif': ['Arial',
                                'Bitstream Vera Sans',
                                'Lucida Grande',
                                'Verdana',
                                'Geneva',
                                'Lucid',
                                'Helvetica',
                                'Avant Garde',
                                'sans-serif'],
            'font.serif': ['Bitstream Vera Serif',
                           'DejaVu Serif',
                           'New Century Schoolbook',
                           'Century Schoolbook L',
                           'Utopia',
                           'ITC Bookman',
                           'Bookman',
                           'Nimbus Roman No9 L',
                           'Times New Roman',
                           'Times',
                           'Palatino',
                           'Charter',
                           'serif'],
            'agg.path.chunksize': 1000,
            }
mpl.rcParams.update(rcParams)

==> fivecentplots-0.4.0.tar.gz: fivecentplots-0.4.0/fivecentplots/themes/white.py <==
#########################################################
# Figure layout defaults
#########################################################
fcp_params = {'ax_edge_color': '#555555',
              'ax_fill_color': '#ffffff',
              'ax_size': [400,400],  # [width, height]
              'box_divider_color': '#bbbbbb',
              'box_fill_color': '#eeeeee',
              'box_group_title_edge_color': '#ffffff',
              'box_group_title_fill_color': '#ffffff',
              'box_group_title_font_size': 13,
              'box_group_title_font_color': '#666666',
              'box_group_title_font_style': 'normal',
              'box_group_title_font_weight': 'normal',
              'box_group_label_edge_color': '#555555',
              'box_group_label_font_size': 12,
              'box_group_label_font_color': '#666666',
              'box_group_label_font_style': 'normal',
              'box_group_label_font_weight': 'normal',
              'cbar_size': 30,
              'cmap': 'inferno',
              'dpi': 100,
              'fig_edge_color': '#ffffff',
              'fig_fill_color': '#ffffff',
              'grid_major_color': '#b9b9b9',
              'grid_major_style': '-',
              'grid_major_width': 0.9,
              'grid_minor_color': '#cccccc',
              'grid_minor_style': '-',
              'grid_minor_width': 0.5,
              'label_color': 'k',
              'label_font_size': 14,
              'label_style': 'italic',
              'label_weight': 'bold',
              'label_rc_edge_color': '#ffffff',
              'label_rc_fill_color': '#888888',
              'label_rc_font_size': 16,
              'label_rc_text_color': '#ffffff',
              'label_rc_text_style': 'normal',
              'label_rc_text_weight': 'bold',
              'label_rc_size': 30,
              'legend_fill_color': '#ffffff',
              'legend_edge_color': '#ffffff',
              'legend_font_size': 12,
              'legend_points': 1,
              'legend_title': '',
              'lines_width': 1,
              'marker_size': 7,
              'marker_type': 'o',
              'tick_labels_font_size': 12,
              'tick_labels_color': '#000000',
              'ticks_major_color': '#aaaaaa',
              'ticks_minor_color': '#bbbbbb',
              'ticks_major_length': 6,
              'ticks_major_width': 1.8,
              'title_fill_color': '#ffffff',
              'title_edge_color': '#ffffff',
              'title_font_color': '#333333',
              'title_font_size': 18,
              'title_font_weight': 'bold',
              'title_wrap_edge_color': '#5f5f5f',
              'title_wrap_fill_color': '#5f5f5f',
              'title_wrap_font_size': 16,
              'title_wrap_font_color': '#ffffff',
              'title_wrap_font_style': 'normal',
              'title_wrap_font_weight': 'bold',
              'title_wrap_size': 30,
              }

#########################################################
# New color schemes
#########################################################

# colors = []

####################################################
# Default marker scheme
####################################################

# markers = []

####################################################
# Matplotlib default overrides
####################################################
import matplotlib as mpl
rcParams = {'font.cursive': ['Apple Chancery',
                             'Textile',
                             'Zapf Chancery',
                             'Sand',
                             'cursive'],
            'font.fantasy': ['Comic Sans MS',
                             'Chicago',
                             'Charcoal',
                             'ImpactWestern',
                             'fantasy'],
            'font.monospace': ['Bitstream Vera Sans Mono',
                               'DejaVu Sans Mono',
                               'Andale Mono',
                               'Nimbus Mono L',
                               'Courier New',
                               'Courier',
                               'Fixed',
                               'Terminal',
                               'monospace'],
            'font.sans-serif': ['Arial',
                                'Bitstream Vera Sans',
                                'Lucida Grande',
                                'Verdana',
                                'Geneva',
                                'Lucid',
                                'Helvetica',
                                'Avant Garde',
                                'sans-serif'],
            'font.serif': ['Bitstream Vera Serif',
                           'DejaVu Serif',
                           'New Century Schoolbook',
                           'Century Schoolbook L',
                           'Utopia',
                           'ITC Bookman',
                           'Bookman',
                           'Nimbus Roman No9 L',
                           'Times New Roman',
                           'Times',
                           'Palatino',
                           'Charter',
                           'serif'],
            'agg.path.chunksize': 1000,
            }
mpl.rcParams.update(rcParams)
